/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: settings.h 277 2005-08-24 16:52:02Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_SETTINGS_H
#define AQBANKING_KDE_SETTINGS_H

class KBanking;

class QBPluginDescrListView;


#include "settings.ui.h"



class KBankingSettings: public KBankingSettingsUi {
  Q_OBJECT
private:
  KBanking *_banking;
  QBPluginDescrListView *_providerListView;

public:
  KBankingSettings(KBanking *ab,
                   QWidget* parent = 0,
                   const char* name = 0, WFlags fl = 0);
  ~KBankingSettings();

  int init();
  int fini();

public slots:
  void backendRescan();
  void backendEnable();
  void backendDisable();
  void backendSetup();
};










#endif /* AQBANKING_KDE_SETTINGS_H */
